/**
 * @file
 * Provides Intense loader.
 *
 * Intense video full screen requires Blazy 2.x.
 */

(function (Drupal, _db) {

  'use strict';

  /**
   * Intense utility functions.
   *
   * @param {HTMLElement} elm
   *   The Intense gallery HTML element.
   */
  function doIntense(elm) {
    var media = elm.querySelector('.media--video', elm);

    if (media !== null && Drupal.blazyBox) {
      Drupal.blazyBox.attach();
    }

    /**
     * Intense utility functions.
     *
     * @param {Event} e
     *   The event triggering the Intense.
     */
    function triggerIntense(e) {
      // The e.target points to an IMG, and no e.currentTarget with vanilla JS.
      var img = e.target;
      var link = _db.closest(img, '.blazy__intense');
      var media = link.getAttribute('data-media') ? _db.parse(link.getAttribute('data-media')) : {};
      var video = media && media.type === 'video';

      // Build own video fullscreen as Intense is not for video.
      if (video && Drupal.blazyBox) {
        Drupal.blazyBox.open(link.getAttribute('href'));
      }
      else {
        new Intense(img);
      }

      e.preventDefault();
    }

    _db.on(elm, 'click', '[data-intense-trigger]', triggerIntense);
  }

  /**
   * Attaches Intense behavior to HTML element.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.intense = {
    attach: function (context) {
      var items = context.querySelectorAll('[data-intense-gallery]');
      _db.once(_db.forEach(items, doIntense));
    }
  };

})(Drupal, dBlazy);
